@@ -21,7 +21,7 @@
 
 
 #include "connectioneditor.h"
-#include "connectiondetaileditor.h"
+#include "connectioneditordialog.h"
 
 #include "debug.h"
 #include "editoridentitymodel.h"
@@ -106,6 +106,17 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
 
     QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.debug = false"));
     QLoggingCategory::setFilterRules(QStringLiteral("plasma-nm.warning = true"));
+
+    // Initialize first scan and then scan every 15 seconds
+    m_handler->requestScan();
+
+    m_timer = new QTimer(this);
+    m_timer->setInterval(15000);
+    connect(m_timer, &QTimer::timeout, [this] () {
+        m_handler->requestScan();
+        m_timer->start();
+    });
+    m_timer->start();
 }
 
 ConnectionEditor::~ConnectionEditor()
@@ -160,23 +171,6 @@ void ConnectionEditor::initializeMenu()
     action->setData(NetworkManager::ConnectionSettings::Wimax);
     m_menu->addAction(action);
 
-    m_menu->menu()->addSection(i18nc("Virtual hardware devices, eg Bridge, Bond", "Virtual"));
-
-    action = new QAction(i18n("Bond"), this);
-    action->setData(NetworkManager::ConnectionSettings::Bond);
-    m_menu->addAction(action);
-    action = new QAction(i18n("Bridge"), this);
-    action->setData(NetworkManager::ConnectionSettings::Bridge);
-    m_menu->addAction(action);
-    action = new QAction(i18n("VLAN"), this);
-    action->setData(NetworkManager::ConnectionSettings::Vlan);
-    m_menu->addAction(action);
-#if NM_CHECK_VERSION(0, 9, 10)
-    action = new QAction(i18n("Team"), this);
-    action->setData(NetworkManager::ConnectionSettings::Team);
-    m_menu->addAction(action);
-#endif
-
     m_menu->menu()->addSection(i18n("VPN"));
 
     KService::List services = KServiceTypeTrader::self()->query("PlasmaNetworkManagement/VpnUiPlugin");
@@ -189,9 +183,13 @@ void ConnectionEditor::initializeMenu()
     Q_FOREACH (const KService::Ptr & service, services) {
         qCDebug(PLASMA_NM) << "Found VPN plugin" << service->name() << ", type:" << service->property("X-NetworkManager-Services", QVariant::String).toString();
 
+        const QString vpnSubType = service->property("X-NetworkManager-Services-Subtype", QVariant::String).toString();
         action = new QAction(service->name(), this);
         action->setData(NetworkManager::ConnectionSettings::Vpn);
         action->setProperty("type", service->property("X-NetworkManager-Services", QVariant::String));
+        if (!vpnSubType.isEmpty()) {
+            action->setProperty("subtype", vpnSubType);
+        }
         m_menu->addAction(action);
     }
 
@@ -248,8 +246,9 @@ void ConnectionEditor::addConnection(QAction* action)
 {
     NetworkManager::ConnectionSettings::ConnectionType type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toUInt());
     const QString vpnType = action->property("type").toString();
+    const QString vpnSubType = action->property("subtype").toString();
 
-    // qCDebug(PLASMA_NM) << "Adding new connection of type " << type;
+    // qCDebug(PLASMA_NM) << "Adding new connection of type " << type << " and subtype " << vpnSubType;
     if (type == NetworkManager::ConnectionSettings::Vpn && vpnType == "imported") {
         importVpn();
     } else if (type == NetworkManager::ConnectionSettings::Gsm) { // launch the mobile broadband wizard, both gsm/cdma
@@ -307,6 +306,12 @@ void ConnectionEditor::addConnection(QAction* action)
         if (type == NetworkManager::ConnectionSettings::Vpn) {
             NetworkManager::VpnSetting::Ptr vpnSetting = connectionSettings->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
             vpnSetting->setServiceType(vpnType);
+            // Set VPN subtype in case of Openconnect to add support for juniper
+            if (vpnType == QLatin1String("org.freedesktop.NetworkManager.openconnect")) {
+                NMStringMap data = vpnSetting->data();
+                data.insert(QLatin1String("protocol"), vpnSubType);
+                vpnSetting->setData(data);
+            }
             // qCDebug(PLASMA_NM) << "VPN type: " << vpnType;
         }
 
@@ -344,13 +349,13 @@ void ConnectionEditor::addConnection(QAction* action)
 
 void ConnectionEditor::addConnection(const NetworkManager::ConnectionSettings::Ptr& connectionSettings)
 {
-    QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(connectionSettings, true);
-    connect(editor.data(), &ConnectionDetailEditor::accepted,
+    QPointer<ConnectionEditorDialog> editor = new ConnectionEditorDialog(connectionSettings);
+    connect(editor.data(), &ConnectionEditorDialog::accepted,
             [connectionSettings, editor, this] () {
                 qCDebug(PLASMA_NM) << "Adding new connection of type " << NetworkManager::ConnectionSettings::typeAsString(connectionSettings->connectionType());
                 m_handler->addConnection(editor->setting());
             });
-    connect(editor.data(), &ConnectionDetailEditor::finished,
+    connect(editor.data(), &ConnectionEditorDialog::finished,
             [editor] () {
                 if (editor) {
                     editor->deleteLater();
@@ -479,7 +484,6 @@ void ConnectionEditor::removeConnection()
     }
 
     Q_FOREACH( NetworkManager::Connection::Ptr connection, connections ) {
-
         if (removeConnections) {
             Q_FOREACH (const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
                 NetworkManager::ConnectionSettings::Ptr settings = con->settings();
@@ -489,7 +493,6 @@ void ConnectionEditor::removeConnection()
             }
             m_handler->removeConnection(connection->path());
         }
-
     }
 }
 
@@ -559,12 +562,12 @@ void ConnectionEditor::slotItemDoubleClicked(const QModelIndex &index)
 
     NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(index.data(NetworkModel::UuidRole).toString());
 
-    QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(connection->settings(), false);
-    connect(editor.data(), &ConnectionDetailEditor::accepted,
+    QPointer<ConnectionEditorDialog> editor = new ConnectionEditorDialog(connection->settings());
+    connect(editor.data(), &ConnectionEditorDialog::accepted,
             [editor, connection, this] () {
                 m_handler->updateConnection(connection, editor->setting());
             });
-    connect(editor.data(), &ConnectionDetailEditor::finished,
+    connect(editor.data(), &ConnectionEditorDialog::finished,
             [editor] () {
                 if (editor) {
                     editor->deleteLater();
