@@ -193,6 +193,10 @@ void OpenconnectAuthWidget::readConfig()
             openconnect_passphrase_from_fsid(d->vpninfo);
         }
     }
+    if (!dataMap[NM_OPENCONNECT_KEY_PROTOCOL].isEmpty()) {
+        const QString protocol = dataMap[NM_OPENCONNECT_KEY_PROTOCOL] == "juniper" ? "nc" : "anyconnect";
+        openconnect_set_protocol(d->vpninfo, OC3DUP(protocol.toUtf8().data()));
+    }
 }
 
 void OpenconnectAuthWidget::readSecrets()
@@ -446,7 +450,7 @@ void OpenconnectAuthWidget::processAuthForm(struct oc_auth_form *form)
             PasswordField *le = new PasswordField(this);
             le->setText(value);
             if (opt->type == OC_FORM_OPT_PASSWORD) {
-                le->setPasswordMode(true);
+                le->setPasswordModeEnabled(true);
             }
             if (!focusSet && le->text().isEmpty()) {
                 le->setFocus(Qt::OtherFocusReason);
