@@ -61,13 +61,13 @@ OpenVpnSettingWidget::OpenVpnSettingWidget(const NetworkManager::VpnSetting::Ptr
     d->setting = setting;
 
     d->ui.x509KeyPassword->setPasswordOptionsEnabled(true);
-    d->ui.x509KeyPassword->setPasswordOptionEnabled(PasswordField::NotRequired, true);
+    d->ui.x509KeyPassword->setPasswordNotRequiredEnabled(true);
     d->ui.passPassword->setPasswordOptionsEnabled(true);
-    d->ui.passPassword->setPasswordOptionEnabled(PasswordField::NotRequired, true);
+    d->ui.passPassword->setPasswordNotRequiredEnabled(true);
     d->ui.x509PassKeyPassword->setPasswordOptionsEnabled(true);
-    d->ui.x509PassKeyPassword->setPasswordOptionEnabled(PasswordField::NotRequired, true);
+    d->ui.x509PassKeyPassword->setPasswordNotRequiredEnabled(true);
     d->ui.x509PassPassword->setPasswordOptionsEnabled(true);
-    d->ui.x509PassPassword->setPasswordOptionEnabled(PasswordField::NotRequired, true);
+    d->ui.x509PassPassword->setPasswordNotRequiredEnabled(true);
 
     // use requesters' urlSelected signals to set other requester's startDirs to save clicking
     // around the filesystem
@@ -80,6 +80,10 @@ OpenVpnSettingWidget::OpenVpnSettingWidget(const NetworkManager::VpnSetting::Ptr
 
     connect(d->ui.btnAdvanced, &QPushButton::clicked, this, &OpenVpnSettingWidget::showAdvanced);
 
+    // Connect for setting check
+    watchChangedSetting();
+
+    // Connect for validity check
     connect(d->ui.gateway, &QLineEdit::textChanged, this, &OpenVpnSettingWidget::slotWidgetChanged);
 
     KAcceleratorManager::manage(this);
@@ -196,8 +200,6 @@ QVariantMap OpenVpnSettingWidget::setting() const
         // key password
         if (!d->ui.x509KeyPassword->text().isEmpty()) {
             secretData.insert(QLatin1String(NM_OPENVPN_KEY_CERTPASS), d->ui.x509KeyPassword->text());
-        } else {
-            secretData.remove(QLatin1String(NM_OPENVPN_KEY_CERTPASS));
         }
         handleOnePasswordType(d->ui.x509KeyPassword, QLatin1String(NM_OPENVPN_KEY_CERTPASS"-flags"), data);
         break;
@@ -223,14 +225,10 @@ QVariantMap OpenVpnSettingWidget::setting() const
         // username
         if (!d->ui.passUserName->text().isEmpty()) {
             data.insert(QLatin1String(NM_OPENVPN_KEY_USERNAME), d->ui.passUserName->text());
-        } else {
-            data.remove(QLatin1String(NM_OPENVPN_KEY_USERNAME));
         }
         // password
         if (!d->ui.passPassword->text().isEmpty()) {
-            secretData.insert(QLatin1String(NM_OPENVPN_KEY_PASSWORD), d->ui.passPassword->text());
-        } else {
-            secretData.remove(QLatin1String(NM_OPENVPN_KEY_PASSWORD));
+            secretData.insert(QLatin1String(NM_OPENVPN_KEY_PASSWORD ), d->ui.passPassword->text());
         }
         handleOnePasswordType(d->ui.passPassword, QLatin1String(NM_OPENVPN_KEY_PASSWORD"-flags"), data);
         // ca
@@ -241,8 +239,6 @@ QVariantMap OpenVpnSettingWidget::setting() const
         // username
         if (!d->ui.x509PassUsername->text().isEmpty()) {
             data.insert(QLatin1String(NM_OPENVPN_KEY_USERNAME), d->ui.x509PassUsername->text());
-        } else {
-            data.remove(QLatin1String(NM_OPENVPN_KEY_USERNAME));
         }
         // ca
         data.insert(QLatin1String(NM_OPENVPN_KEY_CA), d->ui.x509PassCaFile->url().toLocalFile());
@@ -253,15 +249,11 @@ QVariantMap OpenVpnSettingWidget::setting() const
         // key password
         if (!d->ui.x509PassKeyPassword->text().isEmpty()) {
             secretData.insert(QLatin1String(NM_OPENVPN_KEY_CERTPASS), d->ui.x509PassKeyPassword->text());
-        } else {
-            secretData.remove(QLatin1String(NM_OPENVPN_KEY_CERTPASS));
         }
         handleOnePasswordType(d->ui.x509PassKeyPassword, QLatin1String(NM_OPENVPN_KEY_CERTPASS"-flags"), data);
         // password
         if (!d->ui.x509PassPassword->text().isEmpty()) {
             secretData.insert(QLatin1String(NM_OPENVPN_KEY_PASSWORD), d->ui.x509PassPassword->text());
-        } else {
-            secretData.remove(QLatin1String(NM_OPENVPN_KEY_PASSWORD));
         }
         handleOnePasswordType(d->ui.x509PassPassword, QLatin1String(NM_OPENVPN_KEY_PASSWORD"-flags"), data);
         break;
