@@ -38,7 +38,6 @@ PptpAuthWidget::PptpAuthWidget(const NetworkManager::VpnSetting::Ptr &setting, Q
     Q_D(PptpAuthWidget);
     d->setting = setting;
     d->ui.setupUi(this);
-    connect(d->ui.chkShowPassword, &QCheckBox::toggled, this, &PptpAuthWidget::showPasswordsToggled);
 
     KAcceleratorManager::manage(this);
 }
@@ -48,10 +47,9 @@ PptpAuthWidget::~PptpAuthWidget()
     delete d_ptr;
 }
 
-QVariantMap PptpAuthWidget::setting(bool agentOwned) const
+QVariantMap PptpAuthWidget::setting() const
 {
     Q_D(const PptpAuthWidget);
-    Q_UNUSED(agentOwned)
 
     NMStringMap secrets;
     QVariantMap secretData;
@@ -63,13 +61,3 @@ QVariantMap PptpAuthWidget::setting(bool agentOwned) const
     secretData.insert("secrets", QVariant::fromValue<NMStringMap>(secrets));
     return secretData;
 }
-
-void PptpAuthWidget::showPasswordsToggled(bool show)
-{
-    Q_D(PptpAuthWidget);
-    if (show) {
-        d->ui.lePassword->setEchoMode(QLineEdit::Normal);
-    } else {
-        d->ui.lePassword->setEchoMode(QLineEdit::Password);
-    }
-}
